==> dl.php?src=linea21_1_3_1.zip: linea21/languages/es/lang_user.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['user']['section'] = "usuarios";

/*	nommage des modules
*  	*/
$lang['user']['name']='usuario';
$lang['user']['confirm_add'] = "usuario añadido correctamente";
$lang['user']['confirm_mod'] = "usuario actualizado correctamente";
$lang['user']['confirm_modpass'] = "contraseña generada correctamente";
$lang['user']['confirm_sup'] ="usuario eliminado correctamente";
$lang['user']['confirm_changetype']="perfil de usuario actualizado correctamente";
$lang['user']['confirm_public'] = 'Cuenta creada correctamente. La contraseña ha sido enviada a su email.';


/*	nommage rubrique module
*  	*/
$lang['user']['add']= 'Añadir un nuevo '.$lang['user']['name'];
$lang['user']['mod']= 'Editar '.$lang['user']['name'];
$lang['user']['sup']= 'Eliminar '.$lang['user']['name'];
$lang['user']['det']= ucfirst($lang['user']['name']) . ' detalles';
$lang['user']['list']= 'Ver usuarios';


$lang['user']['h1_public_comment_insc']='Puede subscribirse y participar en nuestros grupos de trabajo. Una vez se haya registrado, recibirá un correo con la contraseña. Puede modificar la contraseña asignada si lo desea.';
$lang['user']['h1_public_comment_auth']='Autentifíquese para acceder sus datos personales y a los grupos de trabajo.';
$lang['user']['h1_public_comment']='Preséntese a la comunidad a través de su perfil.';

/*	nommage public
*  	*/

$lang['user']['p_mod']= 'Cambiar perfil de usuario';
$lang['user']['p_mod_table_summary']='Editar formulario de perfil';
$lang['user']['info_mail']= 'Si modifica su dirección de email, se le asignará y enviará una nueva contraseña.';
$lang['user']['info_password']=  '¡Complete los siguientes campos SOLAMENTE si desea cambiar su contraseña!';
$lang['user']['p_new_password']=  'Nueva contraseña';
$lang['user']['p_new_password_confirm']=  'contraseña (confirmación) ';
$lang['user']['p_confirm_mod'] = "Perfil actualizado correctamente";
$lang['user']['p_confirm_back'] = "Haga click aquí para volver a Inicio";
$lang['user']['info_inscription'] = "¿Está usted registrado?";
$lang['user']['info_inscription2'] = "Haga click aquí para crear una cuenta";
$lang['user']['info_inscription3'] = "Las subscripciones le permiten participar en los diferentes grupos de trabajo.";
$lang['user']['info_inscription4'] = "Una vez se haya registrado, recibirá una contraseña en su email. Posteriormente, podrá modificar la contraseña si lo desea.";
$lang['user']['info_inscription5'] = "¡Atención, las cookies del navegador deben estar habilitadas para la autenticación!";

/*	nommage rubrique add / mod /det
*  	*/
$lang['user']['add_title']='Añadir un nuevo '.$lang['user']['name'];
$lang['user']['mod_title']='Editar '.$lang['user']['name'];


/*	check integrité des données
*  	*/
$lang['user']['login_used'] = 'Este usuario ya está en uso. Por favor, seleccione otro.';
$lang['user']['login_tooshort'] = 'Su usuario no es suficientemente largo (mínimo 5 caracteres).';
$lang['user']['login_toolong'] = 'Su usuario es demasiado largo (máximo 20 caracteres).';
$lang['user']['login_prohibited'] = 'Su usuario contiene caracteres no permitidos.';
$lang['user']['pass_tooshort'] = 'Su contraseña no es suficientemente larga (mínimo 5 caracteres).';
$lang['user']['pass_toolong'] = 'Su contraseña es demasiado larga (máximo 15 caracteres).';
$lang['user']['pass_not_same'] = 'La contraseña debe tener valores similares.';
$lang['user']['invalid_mail'] = 'Email no valido';


/*	nommage élément rubrique
*  	*/
$lang['user']['type']='perfil de '.$lang['user']['name'];
$lang['user']['type_simple']= $lang['user']['name'].' simple';
$lang['user']['type_privilege']=$lang['user']['name'].' avanzado';
$lang['user']['type_admin']='administrador';
$lang['user']['pseudo']='nickname';
$lang['user']['email']='email';
$lang['user']['profile']=$lang['user']['name'].' perfil';



$lang['user']['rights']='Permisos por módulos';
$lang['user']['set_rights']='Añadir permisos por módulos';
$lang['user']['update_rights']='Editar permisos por módulos';
$lang['user']['norights']='sin permisos';
$lang['user']['redactorrights']='editor';
$lang['user']['animatorrights']='moderador';
$lang['user']['adminrights']='administrador';
$lang['user']['managerrights']='gestor';
$lang['user']['login']='usuario';
$lang['user']['password']='contraseña';
$lang['user']['email']='email';
$lang['user']['groupe']='grupo';
$lang['user']['date_record']='fecha de registro';
$lang['user']['actions']='acciones';


$lang['user']['email_display']='Email público';
$lang['user']['city']='Ciudad';
$lang['user']['birthdate']='Fecha de nacimiento';
$lang['user']['leisures']='Aficiones';
$lang['user']['job']='Trabajo';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar actual';
$lang['user']['quotation']='Cotización';
$lang['user']['signature']='Firma';
$lang['user']['comment']="Comentarios sobre este ".$lang['user']['name'];


/*	nommage quickbox
*  	*/
$lang['user']['qb_titleadd']=' usuarios agregados recientemente';
$lang['user']['qb_titlemod']=' usuarios modificados recientemente';
$lang['user']['qb_titlesup']=' usuarios eliminados recientemente';


$lang['user']['new_password']='Asignar nueva contraseña';
$lang['user']['2ADMIN_USER']='Definir usuario como administrador';
$lang['user']['2SIMPLE_USER']='Definir usuario como usuario estandar';

/*	divers
*  	*/
$lang['user']['selectgroup']='-- Mostrar por grupo --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='usuario(s) en la base de datos.';
$lang['user']['statut_filter']='Mostrar por estados';
$lang['user']['all']='Mostrar lista completa';
$lang['user']['noresult']='No existen usuarios con este criterio';


/*	messages
*  	*/
$lang['user']['admin_type_info']="El usuario es administrador. Para asignar permisos, modifique el perfil de usuario en 'usuario detalles'.";



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Para añadir un nuevo usuario, inserte el nombre de usuario y dirección de email en el formulario.';
$lang['user']['help_add2']='Si desea generar un usuario con privilegios, debe asignarle permisos en los distintos módulos.';
$lang['user']['help_add3']='Completado el formulario, revise los valores en el resumen.';
$lang['user']['help_add4']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';
$lang['user']['help_add5']='Al crear un nuevo usuario, su contraseña se genera aleatoriamente y se envía.';


$lang['user']['help_list1']='Para mas información haga click en el usuario.';
$lang['user']['help_list2']="Para eliminar un usuario, haga click en el icono 'eliminar usuario'.";
$lang['user']['help_list3']="Para editar un usuario, haga click en el icono 'editar usuario'.";
$lang['user']['help_list4']='Para visualizar los usuarios por grupo específico, mostrar por grupos.';
$lang['user']['help_list5']='Para visualizar los usuarios por orden alfabético, mostrar por orden alfabético.';
$lang['user']['help_list6']='Para añadir un nuevo usuario, haga click en "añadir nuevo usuario".';
$lang['user']['help_list7']="Si desea realizar búsquedas dentro del módulo 'usuarios', haga click en 'buscar'.";


$lang['user']['help_mod1']='Para editar un usuario, inserte la información requerida en el formulario.';
$lang['user']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['user']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['user']['help_det1']="Para eliminar un usuario, haga click en el icono 'eliminar usuario'.";
$lang['user']['help_det2']="Para editar un usuario, haga click en el icono 'editar usuario'.";

$lang['user']['help_sup1']="Para abortar la eliminación, haga click en 'cancelar'.";



/*	mail
**/
$lang['user']['mail_add_subject']='Su cuenta ha sido generada';
$lang['user']['mail_add_body1']='Su cuenta ha sido generada correctamente.';
$lang['user']['mail_add_body2']='Ya tiene acceso a su cuenta privada. Los parámetros de acceso son: ';
$lang['user']['mail_head']="Únase a nosotros en ";
$lang['user']['mail_bottom']="Para cualquier pregunta relacionada con su acceso ";

$lang['user']['mail_changemail_subject']='Confirmación de cambio de email/contraseña';
$lang['user']['mail_changemail_body1']='Le enviamos este correo debido a un cambio en su dirección de email. Por razones de seguridad, se le asigará una nueva contraseña.';
$lang['user']['mail_changemail_body2']='Si lo desea, aún puede modificar la contraseña accediendo a su perfil de usuario';
$lang['user']['mail_changepass_subject']='Nueva contraseña';
$lang['user']['mail_changepass_body1']='Le enviamos este correo debido que usted ha modificado su contraseña, o se ha generado una nueva contraseña para usted.';

?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/es/lang_user.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['user']['section'] = "usuarios";

/*	nommage des modules
 *  	*/
$lang['user']['name']='usuario';
$lang['user']['confirm_add'] = "usuario añadido correctamente";
$lang['user']['confirm_mod'] = "usuario actualizado correctamente";
$lang['user']['confirm_modpass'] = "contraseña generada correctamente";
$lang['user']['confirm_sup'] ="usuario eliminado correctamente";
$lang['user']['confirm_changetype']="perfil de usuario actualizado correctamente";
$lang['user']['confirm_public'] = 'Cuenta creada correctamente. La contraseña ha sido enviada a su email.';


/*	nommage rubrique module
 *  	*/
$lang['user']['add']= 'Añadir un nuevo '.$lang['user']['name'];
$lang['user']['mod']= 'Editar '.$lang['user']['name'];
$lang['user']['sup']= 'Eliminar '.$lang['user']['name'];
$lang['user']['det']= ucfirst($lang['user']['name']) . ' detalles';
$lang['user']['list']= 'Ver usuarios';


$lang['user']['h1_public_comment_insc']='Puede subscribirse y participar en nuestros grupos de trabajo. Una vez se haya registrado, recibirá un correo con la contraseña. Puede modificar la contraseña asignada si lo desea.';
$lang['user']['h1_public_comment_auth']='Autentifíquese para acceder sus datos personales y a los grupos de trabajo.';
$lang['user']['h1_public_comment']='Preséntese a la comunidad a través de su perfil.';

/*	nommage public
 *  	*/

$lang['user']['p_mod']= 'Cambiar perfil de usuario';
$lang['user']['forgot_pass']= 'Contraseña olvidada';
$lang['user']['p_mod_table_summary']='Editar formulario de perfil';
$lang['user']['info_mail']= 'Si modifica su dirección de email, se le asignará y enviará una nueva contraseña.';
$lang['user']['info_password']=  '¡Complete los siguientes campos SOLAMENTE si desea cambiar su contraseña!';
$lang['user']['p_new_password']=  'Nueva contraseña';
$lang['user']['p_new_password_confirm']=  'contraseña (confirmación) '
$lang['user']['new_password_confirmation']=  'A new password has been sent to you by email.'; // @todo translation
$lang['user']['p_confirm_mod'] = "Perfil actualizado correctamente";
$lang['user']['p_confirm_back'] = "Haga click aquí para volver a Inicio";
$lang['user']['info_inscription'] = "¿Está usted registrado?";
$lang['user']['info_inscription2'] = "Haga click aquí para crear una cuenta";
$lang['user']['info_inscription3'] = "Las subscripciones le permiten participar en los diferentes grupos de trabajo.";
$lang['user']['info_inscription4'] = "Una vez se haya registrado, recibirá una contraseña en su email. Posteriormente, podrá modificar la contraseña si lo desea.";
$lang['user']['info_inscription5'] = "¡Atención, las cookies del navegador deben estar habilitadas para la autenticación!";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['user']['add_title']='Añadir un nuevo '.$lang['user']['name'];
$lang['user']['mod_title']='Editar '.$lang['user']['name'];


/*	check integrité des données
 *  	*/
$lang['user']['login_used'] = 'Este usuario ya está en uso. Por favor, seleccione otro.';
$lang['user']['login_tooshort'] = 'Su usuario no es suficientemente largo (mínimo 5 caracteres).';
$lang['user']['login_toolong'] = 'Su usuario es demasiado largo (máximo 20 caracteres).';
$lang['user']['login_prohibited'] = 'Su usuario contiene caracteres no permitidos.';
$lang['user']['pass_tooshort'] = 'Su contraseña no es suficientemente larga (mínimo 5 caracteres).';
$lang['user']['pass_toolong'] = 'Su contraseña es demasiado larga (máximo 15 caracteres).';
$lang['user']['pass_not_same'] = 'La contraseña debe tener valores similares.';
$lang['user']['invalid_mail'] = 'Email no valido';


/*	nommage élément rubrique
 *  	*/
$lang['user']['type']='perfil de '.$lang['user']['name'];
$lang['user']['type_simple']= $lang['user']['name'].' simple';
$lang['user']['type_privilege']=$lang['user']['name'].' avanzado';
$lang['user']['type_admin']='administrador';
$lang['user']['pseudo']='nickname';
$lang['user']['email']='email';
$lang['user']['workgroups']='Workgroups subscription'; // @todo translation
$lang['user']['profile']=$lang['user']['name'].' perfil';



$lang['user']['rights']='Permisos por módulos';
$lang['user']['set_rights']='Añadir permisos por módulos';
$lang['user']['update_rights']='Editar permisos por módulos';
$lang['user']['norights']='sin permisos';
$lang['user']['redactorrights']='editor';
$lang['user']['animatorrights']='moderador';
$lang['user']['adminrights']='administrador';
$lang['user']['managerrights']='gestor';
$lang['user']['login']='usuario';
$lang['user']['password']='contraseña';
$lang['user']['email']='email';
$lang['user']['groupe']='grupo';
$lang['user']['date_record']='fecha de registro';
$lang['user']['actions']='acciones';


$lang['user']['email_display']='Email público';
$lang['user']['city']='Ciudad';
$lang['user']['birthdate']='Fecha de nacimiento';
$lang['user']['leisures']='Aficiones';
$lang['user']['job']='Trabajo';
$lang['user']['avatar']='Avatar';
$lang['user']['current_avatar']='Avatar actual';
$lang['user']['quotation']='Cotización';
$lang['user']['signature']='Firma';
$lang['user']['comment']="Comentarios sobre este ".$lang['user']['name'];


/*	nommage quickbox
 *  	*/
$lang['user']['qb_titleadd']=' usuarios agregados recientemente';
$lang['user']['qb_titlemod']=' usuarios modificados recientemente';
$lang['user']['qb_titlesup']=' usuarios eliminados recientemente';


$lang['user']['new_password']='Asignar nueva contraseña';
$lang['user']['2ADMIN_USER']='Definir usuario como administrador';
$lang['user']['2SIMPLE_USER']='Definir usuario como usuario estandar';

/*	divers
 *  	*/
$lang['user']['selectgroup']='-- Mostrar por grupo --';
$lang['user']['alphabetical']=' [A-Z] ';
$lang['user']['nb_total']='usuario(s) en la base de datos.';
$lang['user']['statut_filter']='Mostrar por estados';
$lang['user']['all']='Mostrar lista completa';
$lang['user']['noresult']='No existen usuarios con este criterio';


/*	messages
 *  	*/
$lang['user']['admin_type_info']="El usuario es administrador. Para asignar permisos, modifique el perfil de usuario en 'usuario detalles'.";



/*	rubrique d'aide

*  	*/
$lang['user']['help_add1']='Para añadir un nuevo usuario, inserte el nombre de usuario y dirección de email en el formulario.';
$lang['user']['help_add2']='Si desea generar un usuario con privilegios, debe asignarle permisos en los distintos módulos.';
$lang['user']['help_add3']='Completado el formulario, revise los valores en el resumen.';
$lang['user']['help_add4']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';
$lang['user']['help_add5']='Al crear un nuevo usuario, su contraseña se genera aleatoriamente y se envía.';


$lang['user']['help_list1']='Para mas información haga click en el usuario.';
$lang['user']['help_list2']="Para eliminar un usuario, haga click en el icono 'eliminar usuario'.";
$lang['user']['help_list3']="Para editar un usuario, haga click en el icono 'editar usuario'.";
$lang['user']['help_list4']='Para visualizar los usuarios por grupo específico, mostrar por grupos.';
$lang['user']['help_list5']='Para visualizar los usuarios por orden alfabético, mostrar por orden alfabético.';
$lang['user']['help_list6']='Para añadir un nuevo usuario, haga click en "añadir nuevo usuario".';
$lang['user']['help_list7']="Si desea realizar búsquedas dentro del módulo 'usuarios', haga click en 'buscar'.";


$lang['user']['help_mod1']='Para editar un usuario, inserte la información requerida en el formulario.';
$lang['user']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['user']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['user']['help_det1']="Para eliminar un usuario, haga click en el icono 'eliminar usuario'.";
$lang['user']['help_det2']="Para editar un usuario, haga click en el icono 'editar usuario'.";

$lang['user']['help_sup1']="Para abortar la eliminación, haga click en 'cancelar'.";



/*	mail
 **/
$lang['user']['mail_add_subject']='Su cuenta ha sido generada';
$lang['user']['mail_add_body1']='Su cuenta ha sido generada correctamente.';
$lang['user']['mail_add_body2']='Ya tiene acceso a su cuenta privada. Los parámetros de acceso son: ';
$lang['user']['mail_head']="Únase a nosotros en ";
$lang['user']['mail_bottom']="Para cualquier pregunta relacionada con su acceso ";

$lang['user']['mail_changemail_subject']='Confirmación de cambio de email/contraseña';
$lang['user']['mail_changemail_body1']='Le enviamos este correo debido a un cambio en su dirección de email. Por razones de seguridad, se le asigará una nueva contraseña.';
$lang['user']['mail_changemail_body2']='Si lo desea, aún puede modificar la contraseña accediendo a su perfil de usuario';

$lang['user']['mail_changepass_subject']='Nueva contraseña';
$lang['user']['mail_changepass_body1']='Le enviamos este correo debido que usted ha modificado su contraseña, o se ha generado una nueva contraseña para usted.';
$lang['user']['mail_changepass_body2']='Si lo desea, aún puede modificar la contraseña accediendo a su perfil de usuario';

$lang['user']['mail_forgotpass_subject']='Contraseña olvidada';
$lang['user']['mail_forgotpass_body1']='You ask for a new password. Please click the following url (or copy-paste it into your browser) to process.' ; // @todo translation
$lang['user']['mail_forgotpass_body2']='If you did not ask for a new password, just ignore that email.'; // @todo translation
?>
